nlptools.morph
==============


.. automodule:: nlptools.morph
   :members:
   :undoc-members:
   :show-inheritance:


.. toctree::
   :maxdepth: 1
   :caption: Modules:

   morph/morph_tagger
   morph/charsets
   morph/lemmatizeSentence
   morph/tokenizers_words